local OptionsFrame = CreateFrame("Frame", nil, InterfaceOptionsFramePanelContainer)
OptionsFrame.name = "CCCounter"
OptionsFrame:RegisterEvent("ADDON_LOADED")
OptionsFrame:Hide()

local previousbox

local function AddCheckbox(text, relativeTo, size, offX, offY, font)
    local checkbox = CreateFrame("CheckButton", nil, OptionsFrame, "UICheckButtonTemplate")
    checkbox:SetPoint("TOPLEFT", relativeTo, "BOTTOMLEFT", offX, offY)
	checkbox:SetSize(size, size)
    checkbox.text:SetFontObject(font)
    checkbox.text:SetText("  " .. text)
    previousbox = checkbox
    return checkbox
end

local function AddTextLabel(text, relativeTo, offX, offY, font)
	local textlabel = OptionsFrame:CreateFontString(nil, "ARTWORK", font)
	if (not relativeTo) then
		textlabel:SetPoint("TOPLEFT", offX, offY)
	else
		textlabel:SetPoint("TOPLEFT", relativeTo, "BOTTOMLEFT", offX, offY)
	end
	textlabel:SetJustifyH("LEFT")
	textlabel:SetFontObject(font)
	textlabel:SetText(text)
	return textlabel
end

local OptionsTitle = AddTextLabel("CCCounter", nil, 16, -16, "GameFontHighlight")
local BoxEnable = AddCheckbox("Enable CCCounter", OptionsTitle, 30, 0, -20, "GameFontHighlight")
local BoxApply = AddCheckbox("Display CC applied", previousbox, 16, 30, 0, "GameFontHighlight")
local BoxRemove = AddCheckbox("Display CC removed", previousbox, 16, 0, 0, "GameFontHighlight")
local BoxCount = AddCheckbox("Count time in CC", previousbox, 16, 0, 0, "GameFontHighlight")
local BoxPlayer = AddCheckbox("Track only player actions", previousbox, 16, 0, 0, "GameFontHighlight")
local BoxTime = AddCheckbox("Show time in frame", previousbox, 16, 0, 0, "GameFontHighlight")
local BoxAuto = AddCheckbox("Auto-report when changing world", previousbox, 16, 0, 0, "GameFontHighlight")

local function CCC_OptionsFrame_OnEvent(self, event, arg1, ...)
	if (event == "ADDON_LOADED") then
		if (CCC_SavedVars.enabled == nil) then
			OptionsFrame.default()
		end

		BoxEnable:SetChecked(CCC_SavedVars.enabled)
		BoxApply:SetChecked(CCC_SavedVars.applied)
		BoxRemove:SetChecked(CCC_SavedVars.removed)
		BoxCount:SetChecked(CCC_SavedVars.count)
		BoxPlayer:SetChecked(CCC_SavedVars.players)
		BoxTime:SetChecked(CCC_SavedVars.timeframe)
		BoxAuto:SetChecked(CCC_SavedVars.auto)
		
		if(BoxTime:GetChecked()) then
			CCCFrame:SetHeight(200)
		end
	end
end

local function CCC_BoxesDisable()
	BoxApply:Disable()
	BoxRemove:Disable()
	BoxCount:Disable()
	BoxPlayer:Disable()
	BoxTime:Disable()
	BoxAuto:Disable()
end

local function CCC_BoxesEnable()
	BoxApply:Enable()
	BoxRemove:Enable()
	BoxCount:Enable()
	BoxPlayer:Enable()
	BoxTime:Enable()
	BoxAuto:Enable()
end

local function CCC_BoxEnableOnClick(self)
	if (BoxEnable:GetChecked() == true) then
		CCC_BoxesEnable()
	else
		CCC_BoxesDisable()
	end
end


function OptionsFrame.default()
	CCC_SavedVars.enabled = true
	CCC_SavedVars.applied = false
	CCC_SavedVars.removed = false
	CCC_SavedVars.count = true
	CCC_SavedVars.players = true
	CCC_SavedVars.timeframe = false
	CCC_SavedVars.auto = false
end

function OptionsFrame.refresh()
	if (CCC_SavedVars.enabled ~= nil) then
		BoxEnable:SetChecked(CCC_SavedVars.enabled)
	end
	
	if (BoxEnable:GetChecked() == true) then
		CCC_BoxesEnable()
	else
		CCC_BoxesDisable()
	end
	
end

function OptionsFrame.okay()
	CCC_SavedVars.enabled = BoxEnable:GetChecked()
	
	CCC_SavedVars.applied = BoxApply:GetChecked()
	CCC_SavedVars.removed = BoxRemove:GetChecked()
	CCC_SavedVars.count = BoxCount:GetChecked()
	CCC_SavedVars.players = BoxPlayer:GetChecked()
	CCC_SavedVars.timeframe = BoxTime:GetChecked()
	CCC_SavedVars.auto = BoxAuto:GetChecked()
	
	if(BoxTime:GetChecked()) then
		CCCFrame:SetHeight(200)
	else
		CCCFrame:SetHeight(130)
	end
end

BoxEnable:SetScript("OnClick", CCC_BoxEnableOnClick)
OptionsFrame:SetScript("OnEvent", CCC_OptionsFrame_OnEvent)
InterfaceOptions_AddCategory(OptionsFrame)
